# -*- coding:utf-8 -*-

from django.core.exceptions import ValidationError
import json


def validate_json(value):
    try:
        json.loads(value, strict=False)
    except ValueError as e:
        raise ValidationError(u"It's not a valid json string.")





# -*- coding:utf-8 -*-

import six
import unittest
from hypothesis import given
import hypothesis.strategies as st
from knob.crypt import *


KEY_CHARS = u"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz01234567890,./~!@#$%^&*()_+-={}|[];:'<>? " + u'"'

TEXT_CHARS = KEY_CHARS + u"汉字中文"


class TestCrypt(unittest.TestCase):
    @given(st.text(alphabet=KEY_CHARS, min_size=0, max_size=128), st.text(alphabet=TEXT_CHARS, min_size=0, max_size=1024))
    def test_enc_dec(self, key, text):
        encrypted = encrypt(text, key)
        decrypted = decrypt(encrypted, key)
        self.assertEqual(text, decrypted)


if __name__ == '__main__':
    unittest.main()



# -*- coding:utf-8 -*-

import six
import json


def get_request_para(request, parsers=None, defaults=None):
    para = {}
    if request.method in ['POST', 'PUT', 'PATCH']:
        try:
            json_str = request.body.decode('utf-8') if six.PY3 else request.body
            json_para = json.loads(json_str, strict=False)
            if isinstance(json_para, dict):
                para.update(json_para)
        except Exception as e:
            pass
    para.update(request.GET.dict())

    if parsers:
        for k, parser in six.iteritems(parsers):
            if callable(parser) and k in para:
                para[k] = parser(para[k])

    if defaults:
        for k, v in six.iteritems(defaults):
            para.setdefault(k, v)

    return para


def get_ip(request):
    if 'HTTP_X_REAL_IP' in request.META:
        return request.META['HTTP_X_REAL_IP']
    else:
        return request.META['REMOTE_ADDR']

